#[non_exhaustive]pub enum SpellAuraPolicyKind {
Gate {
min_stacks: u8,
},
CostBypass,
CooldownBypass,
Override {
replacement: SpellIdx,
shares_base_cooldown: bool,
},
}Expand description
Behavior activated by an aura for one spell.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Gate
Lock the spell until the aura reaches the required stack count.
CostBypass
Waive the primary-resource cost check while the aura is active.
CooldownBypass
Waive the cooldown check while the aura is active.
Override
Replace the spell while the aura is active.